<?php
/**
 * Online-Radar Widget plugin
 *
 * @package     Joomla.Site
 * @subpackage  plg_onlineradar_widget
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * 
 * onlineradar_widget is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * 
 * This product Online-Radar Widget is not affiliated with 
 * or endorsed by The Joomla! Project™. It is not supported or warranted by 
 * The Joomla Project or Open Source Matters. The Joomla!® name and logo is 
 * used under a limited license granted by Open Source Matters the trademark 
 * holder in the United States and other countries.
 * 
 */

defined('_JEXEC') or die;

// consts
/*
 * set option for use offline verion 
 * on widget if service is a unaccessable.*/
define('ONLINERADAR_WIDGET_CAN_USE_OFFLINE_VER', FALSE); 

define('ONLINERADAR_WIDGET_SERVICE_URL', 'http://online-radar.ru');
define('ONLINERADAR_WIDGET_SCRIPT_URL', ONLINERADAR_WIDGET_SERVICE_URL . '/js/usersonline_widget.min.js');
define('ONLINERADAR_WIDGET_IFVISIBLE_URL', 'plugins/system/onlineradar_widget/js/ifvisible.min.js');

/*
 * Constanants for offline version
 */
define('ONLINERADAR_WIDGET_COM_NAME', 'com_onlineradar');
define('ONLINERADARALT_WIDGET_SCRIPT_URL', 'plugins/system/onlineradar_widget/js/onlineradar_widget.min.js');
define('ONLINERADAR_JS_LOADER_SCRIPT_URL', 'plugins/system/onlineradar_widget/js/jsloader.min.js');

// import
jimport('joomla.plugin.plugin');

/**
 * Online-Radar Widget plugin.
 *
 * @since  3.0
 */
class PlgSystemOnlineradar_widget extends JPlugin
{
    /**
     * Append JQuery script in noConfict mode
     *
     * @param void
     * @access private
     */
    private static function addJQuery(){
        $document = JFactory::getDocument();
        
        if (version_compare(JVERSION, '3.0', 'lt'))
        {
            // Joomla version lower 3.0
            JHTML::_('behavior.framework');
            // load jQuery, if not loaded before
            if (!JFactory::getApplication()->get('jquery'))
            {
                JFactory::getApplication()->set('jquery', true);
                // add jQuery
                $document->addScript('https://ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js');
                $document->addScriptDeclaration('jQuery.noConflict();');
            }
        } else {
            /* use JQuery framework in noConflict mode */
            JHtml::_('jquery.framework');
        }
    }
    
    /**
     * Append scripts
     *
     * @param array $param An object containing the module parameters
     * @access public
     */
    public static function addScripts($doc, $param){
        $txtcolor = $param->get('txtcolor', '#337ab7');
        $bgcolor = $param->get('bgcolor', '#fff');
        $bghovercolor = $param->get('bghovercolor', '#eee');
        $cntcolor = $param->get('cntcolor', '#fff');
        $bgcntcolor = $param->get('bgcntcolor', '#777');
        $txtfont = htmlspecialchars($param->get('txtfont', '\'Helvetica Neue\', Helvetica, Arial, sans-serif'));
        $options = $param->get('closecb', 0)*1
                + $param->get('flipcb', 0)*2
                + $param->get('hidecb', 0)*4;
        $position = $param->get('position', 16) . $options;

        $doc->addScript(JURI::base() . ONLINERADAR_WIDGET_IFVISIBLE_URL);
        
        self::addJQuery();
        $doc->addScript(ONLINERADAR_WIDGET_SCRIPT_URL);
        
        if (ONLINERADAR_WIDGET_CAN_USE_OFFLINE_VER === TRUE){
            $doc->addScript(JURI::base() . ONLINERADAR_JS_LOADER_SCRIPT_URL);
            $doc->addScript(JURI::base() . ONLINERADARALT_WIDGET_SCRIPT_URL);
            $doc->addScriptDeclaration('jQuery(window).on(\'load\', function(){'
                . 'onlineradar_loader("'.ONLINERADAR_WIDGET_SERVICE_URL
                . '","'.ONLINERADAR_WIDGET_COM_NAME.'","'
                . $txtcolor.'","'.$bgcolor.'","'.$bghovercolor.'","'.$cntcolor
                . '","'.$bgcntcolor.'","'.$txtfont.'","'.$position.'");});');
        } else {
            $doc->addScriptDeclaration('jQuery(window).on(\'load\', function(){'
                . 'usersonline_widget("'.ONLINERADAR_WIDGET_SERVICE_URL
                . '","' . $txtcolor.'","'.$bgcolor.'","'.$bghovercolor.'","'.$cntcolor
                . '","'.$bgcntcolor.'","'.$txtfont.'","'.$position.'");});');
        }
        return true;
    }
    
    /**
     * Append HTML-Block for widget generate
     *
     * @param none
     * @access public
     * @return none
     */
    public static function getBlock(){
        return '<div id="onlineusers_widget"></div>';
    }
    
    /**
     * Method to catch the onAfterDispatch event.
     *
     * This is where we setup the click-through content highlighting for.
     * The highlighting is done with JavaScript so we just
     * need to check a few parameters and the JHtml behavior will do the rest.
     *
     * @return  boolean  True on success
     *
     * @since   2.5
     */
    public function onAfterDispatch(){
        // Check that we are in the site application.
        if (JFactory::getApplication()->isAdmin()){
            return true;
        }
        
        // Adjust the component buffer.
        $doc = JFactory::getDocument();
        $buf = $doc->getBuffer('component');
        $buf .= self::getBlock();
        $doc->setBuffer($buf, 'component');

        return true;
    }

    /**
     * This event is triggered immediately before the framework has rendered the application.
     * 
     * @access public
     * @param none
     * @return boolean
     */
    public function onBeforeRender(){
        return true;
    }
    
    /**
     * This event is triggered after the framework has loaded and initialised 
     * and the router has routed the client request. Routing is the process of 
     * examining the request environment to determine which component should 
     * receive the request. The component optional parameters are then set in 
     * the request object that will be processed when the application is being 
     * dispatched. When this event triggers, the router has parsed the route 
     * and pushed the request parameters into JRequest to be retrieved by the 
     * application.
     * 
     * @access public
     * @param none
     * @return  boolean  True on success
     * 
     */
    public function onAfterRoute(){
        // Check that we are in the site application.
        if (JFactory::getApplication()->isAdmin()){
            return true;
        }
        
        $document = JFactory::getDocument();
        self::addScripts($document, $this->params);
        
        return true;
    }
    
    /**
     * This event is triggered after the framework has loaded and the application initialise method has been called.
     * 
     * @access public
     * @param none
     * @return boolean
     */
    public function onAfterInitialise(){
        return true;
    }
}